==> apache-eventmesh-1.9.0-source.tar.gz: apache-eventmesh-1.9.0-src/eventmesh-common/src/test/java/org/apache/eventmesh/common/loadbalance/WeightTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common.loadbalance;

import org.junit.Assert;
import org.junit.Test;

public class WeightTest {

    @Test
    public void testDecreaseTotal() {
        Weight weight = new Weight(null, 0);
        weight.decreaseTotal(1);
        Assert.assertEquals(-1, weight.getCurrentWeight().get());
    }

    @Test
    public void testIncreaseCurrentWeight() {
        Weight weight = new Weight(null, 10);
        weight.increaseCurrentWeight();
        Assert.assertEquals(10, weight.getCurrentWeight().get());
    }

    @Test
    public void testGetCurrentWeight() {
        Weight weight = new Weight(null, 0);
        Assert.assertEquals(0, weight.getCurrentWeight().get());
    }
}

==> apache-eventmesh-1.12.0-source.tar.gz: apache-eventmesh-1.12.0-src/eventmesh-common/src/test/java/org/apache/eventmesh/common/loadbalance/WeightTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.common.loadbalance;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class WeightTest {

    @Test
    public void testDecreaseTotal() {
        Weight weight = new Weight(null, 0);
        weight.decreaseTotal(1);
        Assertions.assertEquals(-1, weight.getCurrentWeight().get());
    }

    @Test
    public void testIncreaseCurrentWeight() {
        Weight weight = new Weight(null, 10);
        weight.increaseCurrentWeight();
        Assertions.assertEquals(10, weight.getCurrentWeight().get());
    }

    @Test
    public void testGetCurrentWeight() {
        Weight weight = new Weight(null, 0);
        Assertions.assertEquals(0, weight.getCurrentWeight().get());
    }
}
